@@ -114,6 +114,7 @@ def main():
     import output
     import controller
     import trace
+    import template
 
     if not os.path.exists(options.output):
         print "The output device %s is not found." % options.output
@@ -124,6 +125,15 @@ def main():
                "Please specify another TTY device.") % options.output
         return
 
+    output_file = open(options.output)
+    try:
+        if os.isatty(output_file.fileno()):
+            template.enable_color()
+        else:
+            template.disable_color()
+    finally:
+        output_file.close()
+
     tty = tff.DefaultPTY(term, lang, command, sys.stdin)
     try:
         tty.fitsize()
